@@ -7,6 +7,7 @@ import webbrowser
 from importlib.resources import path
 from typing import Any, Union
 
+import pkg_resources
 import typer
 from dotenv import load_dotenv
 
@@ -35,23 +36,23 @@ def download(
     notion_processor.create_scripts(database_id, section_name)
 
 
-def copy_assets():
-    with path(__package__, "web") as assets_folder:
-        src_files = os.listdir(assets_folder)
-        for file_name in src_files:
-            full_file_name = os.path.join(assets_folder, file_name)
-            if os.path.isfile(full_file_name):
-                shutil.copy(full_file_name, CONTENT_DIRECTORY)
+def copy_assets(content_root: str):
+    assets_folder = pkg_resources.resource_filename("nprompter", "web")
+    src_files = os.listdir(assets_folder)
+    for file_name in src_files:
+        full_file_name = os.path.join(assets_folder, file_name)
+        if os.path.isfile(full_file_name):
+            shutil.copy(full_file_name, content_root)
 
 
 @app.command()
-def serve(port: int = 8889):
-
-    copy_assets()
+def serve(port: int = 8889, content_root: Union[str, None] = None):
+    content_root = content_root or CONTENT_DIRECTORY
+    copy_assets(content_root)
 
     class CustomHandler(http.server.SimpleHTTPRequestHandler):
         def __init__(self, *args, **kwargs):
-            super().__init__(*args, directory=CONTENT_DIRECTORY, **kwargs)
+            super().__init__(*args, directory=content_root, **kwargs)
 
         def log_message(self, format: str, *args: Any) -> None:
             pass
